from collections import Set


class HistorySet(Set):
    def __init__(self, data, eidetic=False):
        self.__eidetic__ = eidetic
        self.__data__ = set(data)
        self.__added__ = set([])
        self.__removed__ = set([])

    def __contains__(self, item):
        return item in self.__data__

    def __iter__(self):
        return self.__data__.__iter__()

    def __len__(self):
        return len(self.__data__)

    def __repr__(self):
        return self.__data__.__repr__()

    def add(self, item):
        self.__added__.add(item)
        self.__data__.add(item)

    def remove(self, item):
        if(item not in self.__data__):
            raise KeyError

        if(not self.__eidetic__ and item in self.__added__):
            self.__added__.remove(item)
        else:
            self.__removed__.add(item)
        self.__data__.remove(item)


    def added(self):
        return self.__added__

    def removed(self):
        return self.__removed__


    def reset(self):
        self.__added__.clear()
        self.__removed__.clear()



#!/usr/bin/env python3
from glob import glob
from os.path import basename, splitext

from setuptools import find_packages, setup

setup(name='history-set',
      version="0.1",
      description='A Set implementation that tracks added and removed elements.',
      packages=find_packages('lib'),
      package_dir={'': 'lib'},
      author='Dave Lundgren, Connor Riva, Tjaart van der Walt',
      author_email='dlungren@outsideopen.com, criva@westmont.edu, tjaart@outsideopen.com',
      url='https://bitbucket.org/westmont/history_set',
      py_modules=[splitext(basename(path))[0] for path in glob('lib/*.py')],
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 3',
      ])
